@@ -23,44 +23,13 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class DescribeVerifyTokenRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeVerifyToken')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeVerifyToken','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_FaceRetainedImageUrl(self):
-		return self.get_query_params().get('FaceRetainedImageUrl')
-
-	def set_FaceRetainedImageUrl(self,FaceRetainedImageUrl):
-		self.add_query_param('FaceRetainedImageUrl',FaceRetainedImageUrl)
-
-	def get_UserId(self):
-		return self.get_query_params().get('UserId')
-
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_CallbackSeed(self):
-		return self.get_query_params().get('CallbackSeed')
-
-	def set_CallbackSeed(self,CallbackSeed):
-		self.add_query_param('CallbackSeed',CallbackSeed)
-
-	def get_UserIp(self):
-		return self.get_query_params().get('UserIp')
-
-	def set_UserIp(self,UserIp):
-		self.add_query_param('UserIp',UserIp)
-
-	def get_IdCardBackImageUrl(self):
-		return self.get_query_params().get('IdCardBackImageUrl')
-
-	def set_IdCardBackImageUrl(self,IdCardBackImageUrl):
-		self.add_query_param('IdCardBackImageUrl',IdCardBackImageUrl)
-
 	def get_IdCardNumber(self):
 		return self.get_query_params().get('IdCardNumber')
 
@@ -73,23 +42,47 @@ class DescribeVerifyTokenRequest(RpcRequest):
 	def set_IdCardFrontImageUrl(self,IdCardFrontImageUrl):
 		self.add_query_param('IdCardFrontImageUrl',IdCardFrontImageUrl)
 
+	def get_FaceRetainedImageUrl(self):
+		return self.get_query_params().get('FaceRetainedImageUrl')
+
+	def set_FaceRetainedImageUrl(self,FaceRetainedImageUrl):
+		self.add_query_param('FaceRetainedImageUrl',FaceRetainedImageUrl)
+
+	def get_UserId(self):
+		return self.get_query_params().get('UserId')
+
+	def set_UserId(self,UserId):
+		self.add_query_param('UserId',UserId)
+
 	def get_BizType(self):
 		return self.get_query_params().get('BizType')
 
 	def set_BizType(self,BizType):
 		self.add_query_param('BizType',BizType)
 
+	def get_IdImageUrl(self):
+		return self.get_query_params().get('IdImageUrl')
+
+	def set_IdImageUrl(self,IdImageUrl):
+		self.add_query_param('IdImageUrl',IdImageUrl)
+
 	def get_PassedRedirectUrl(self):
 		return self.get_query_params().get('PassedRedirectUrl')
 
 	def set_PassedRedirectUrl(self,PassedRedirectUrl):
 		self.add_query_param('PassedRedirectUrl',PassedRedirectUrl)
 
-	def get_UserRegistTime(self):
-		return self.get_query_params().get('UserRegistTime')
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
 
-	def set_UserRegistTime(self,UserRegistTime):
-		self.add_query_param('UserRegistTime',UserRegistTime)
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
+
+	def get_CallbackSeed(self):
+		return self.get_query_params().get('CallbackSeed')
+
+	def set_CallbackSeed(self,CallbackSeed):
+		self.add_query_param('CallbackSeed',CallbackSeed)
 
 	def get_BizId(self):
 		return self.get_query_params().get('BizId')
@@ -103,11 +96,11 @@ class DescribeVerifyTokenRequest(RpcRequest):
 	def set_Name(self,Name):
 		self.add_query_param('Name',Name)
 
-	def get_UserPhoneNumber(self):
-		return self.get_query_params().get('UserPhoneNumber')
+	def get_IdCardBackImageUrl(self):
+		return self.get_query_params().get('IdCardBackImageUrl')
 
-	def set_UserPhoneNumber(self,UserPhoneNumber):
-		self.add_query_param('UserPhoneNumber',UserPhoneNumber)
+	def set_IdCardBackImageUrl(self,IdCardBackImageUrl):
+		self.add_query_param('IdCardBackImageUrl',IdCardBackImageUrl)
 
 	def get_CallbackUrl(self):
 		return self.get_query_params().get('CallbackUrl')
