@@ -23,20 +23,13 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class DescribeVerifyUsageRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeVerifyUsage')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeVerifyUsage','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_StartDate(self):
-		return self.get_query_params().get('StartDate')
-
-	def set_StartDate(self,StartDate):
-		self.add_query_param('StartDate',StartDate)
-
 	def get_BizType(self):
 		return self.get_query_params().get('BizType')
 
@@ -47,4 +40,16 @@ class DescribeVerifyUsageRequest(RpcRequest):
 		return self.get_query_params().get('EndDate')
 
 	def set_EndDate(self,EndDate):
-		self.add_query_param('EndDate',EndDate)
\ No newline at end of file
+		self.add_query_param('EndDate',EndDate)
+
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
+
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
+
+	def get_StartDate(self):
+		return self.get_query_params().get('StartDate')
+
+	def set_StartDate(self,StartDate):
+		self.add_query_param('StartDate',StartDate)
\ No newline at end of file
