@@ -23,8 +23,7 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class ModifyDeviceInfoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'ModifyDeviceInfo')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'ModifyDeviceInfo','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
@@ -37,6 +36,12 @@ class ModifyDeviceInfoRequest(RpcRequest):
 	def set_UserDeviceId(self,UserDeviceId):
 		self.add_query_param('UserDeviceId',UserDeviceId)
 
+	def get_BizType(self):
+		return self.get_query_params().get('BizType')
+
+	def set_BizType(self,BizType):
+		self.add_query_param('BizType',BizType)
+
 	def get_Duration(self):
 		return self.get_query_params().get('Duration')
 
@@ -49,14 +54,20 @@ class ModifyDeviceInfoRequest(RpcRequest):
 	def set_ExpiredDay(self,ExpiredDay):
 		self.add_query_param('ExpiredDay',ExpiredDay)
 
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
+
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
+
+	def get_Lang(self):
+		return self.get_query_params().get('Lang')
+
+	def set_Lang(self,Lang):
+		self.add_query_param('Lang',Lang)
+
 	def get_DeviceId(self):
 		return self.get_query_params().get('DeviceId')
 
 	def set_DeviceId(self,DeviceId):
-		self.add_query_param('DeviceId',DeviceId)
-
-	def get_BizType(self):
-		return self.get_query_params().get('BizType')
-
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
\ No newline at end of file
+		self.add_query_param('DeviceId',DeviceId)
\ No newline at end of file
