@@ -23,44 +23,49 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class UpdateVerifySettingRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'UpdateVerifySetting')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'UpdateVerifySetting','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_GuideStep(self):
-		return self.get_query_params().get('GuideStep')
-
-	def set_GuideStep(self,GuideStep):
-		self.add_query_param('GuideStep',GuideStep)
-
-	def get_ResultStep(self):
-		return self.get_query_params().get('ResultStep')
-
-	def set_ResultStep(self,ResultStep):
-		self.add_query_param('ResultStep',ResultStep)
-
-	def get_Solution(self):
-		return self.get_query_params().get('Solution')
-
-	def set_Solution(self,Solution):
-		self.add_query_param('Solution',Solution)
-
-	def get_BizName(self):
-		return self.get_query_params().get('BizName')
-
-	def set_BizName(self,BizName):
-		self.add_query_param('BizName',BizName)
-
 	def get_BizType(self):
 		return self.get_query_params().get('BizType')
 
 	def set_BizType(self,BizType):
 		self.add_query_param('BizType',BizType)
 
+	def get_ResultStep(self):
+		return self.get_query_params().get('ResultStep')
+
+	def set_ResultStep(self,ResultStep):
+		self.add_query_param('ResultStep',ResultStep)
+
+	def get_GuideStep(self):
+		return self.get_query_params().get('GuideStep')
+
+	def set_GuideStep(self,GuideStep):
+		self.add_query_param('GuideStep',GuideStep)
+
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
+
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
+
+	def get_BizName(self):
+		return self.get_query_params().get('BizName')
+
+	def set_BizName(self,BizName):
+		self.add_query_param('BizName',BizName)
+
+	def get_Solution(self):
+		return self.get_query_params().get('Solution')
+
+	def set_Solution(self,Solution):
+		self.add_query_param('Solution',Solution)
+
 	def get_PrivacyStep(self):
 		return self.get_query_params().get('PrivacyStep')
 
