@@ -23,31 +23,18 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class VerifyMaterialRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'VerifyMaterial')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'VerifyMaterial','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_FaceImageUrl(self):
-		return self.get_query_params().get('FaceImageUrl')
+	def get_BizType(self):
+		return self.get_query_params().get('BizType')
 
-	def set_FaceImageUrl(self,FaceImageUrl):
-		self.add_query_param('FaceImageUrl',FaceImageUrl)
-
-	def get_UserId(self):
-		return self.get_query_params().get('UserId')
-
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_IdCardBackImageUrl(self):
-		return self.get_query_params().get('IdCardBackImageUrl')
-
-	def set_IdCardBackImageUrl(self,IdCardBackImageUrl):
-		self.add_query_param('IdCardBackImageUrl',IdCardBackImageUrl)
+	def set_BizType(self,BizType):
+		self.add_query_param('BizType',BizType)
 
 	def get_IdCardNumber(self):
 		return self.get_query_params().get('IdCardNumber')
@@ -55,17 +42,11 @@ class VerifyMaterialRequest(RpcRequest):
 	def set_IdCardNumber(self,IdCardNumber):
 		self.add_query_param('IdCardNumber',IdCardNumber)
 
-	def get_IdCardFrontImageUrl(self):
-		return self.get_query_params().get('IdCardFrontImageUrl')
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
 
-	def set_IdCardFrontImageUrl(self,IdCardFrontImageUrl):
-		self.add_query_param('IdCardFrontImageUrl',IdCardFrontImageUrl)
-
-	def get_BizType(self):
-		return self.get_query_params().get('BizType')
-
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
 
 	def get_BizId(self):
 		return self.get_query_params().get('BizId')
@@ -77,4 +58,28 @@ class VerifyMaterialRequest(RpcRequest):
 		return self.get_query_params().get('Name')
 
 	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+		self.add_query_param('Name',Name)
+
+	def get_IdCardFrontImageUrl(self):
+		return self.get_query_params().get('IdCardFrontImageUrl')
+
+	def set_IdCardFrontImageUrl(self,IdCardFrontImageUrl):
+		self.add_query_param('IdCardFrontImageUrl',IdCardFrontImageUrl)
+
+	def get_IdCardBackImageUrl(self):
+		return self.get_query_params().get('IdCardBackImageUrl')
+
+	def set_IdCardBackImageUrl(self,IdCardBackImageUrl):
+		self.add_query_param('IdCardBackImageUrl',IdCardBackImageUrl)
+
+	def get_FaceImageUrl(self):
+		return self.get_query_params().get('FaceImageUrl')
+
+	def set_FaceImageUrl(self,FaceImageUrl):
+		self.add_query_param('FaceImageUrl',FaceImageUrl)
+
+	def get_UserId(self):
+		return self.get_query_params().get('UserId')
+
+	def set_UserId(self,UserId):
+		self.add_query_param('UserId',UserId)
\ No newline at end of file
